declare type ProgressFn = (progress: number) => void;
declare type SuccessFn = (endpoint: string, md5: string, response: any) => void;
declare type ErrorFn = (error: IUploadChunkError) => void;
interface IConfig {
    file: File;
    endpoint: string;
    /** Size per chunk Kilobyte (KB), must be divisible by 256 */
    chunkSizeKb: number;
    retries?: number;
    headers: Record<string, any>;
    setProgress: ProgressFn;
    onSuccess: SuccessFn;
    onError: ErrorFn;
}
export interface IUploadChunkError {
    code: ErrorCode;
    message: string;
    attemptLeft?: number;
    chunkNumber?: number;
}
export declare enum ErrorCode {
    UPLOAD_CHUNK_FAILED = "UPLOAD_CHUNK_FAILED",
    UPLOAD_CHUNK_ALL_RETRIES_FAILED = "UPLOAD_CHUNK_ALL_RETRIES_FAILED",
    VALIDATION_FAILED = "VALIDATION_FAILED",
    FAILED_HASH_MD5 = "FAILED_HASH_MD5"
}
export default class UploadChunk {
    private _file;
    private _retries;
    private _retryCount;
    private _chunkSize;
    private _endpoint;
    private _chunk;
    private _totalChunk;
    private _chunkIndex;
    private _additionalHeaders;
    private _paused;
    private _success;
    private _setProgress;
    private _setSuccess;
    private _setError;
    private _saveMd5;
    private _reader;
    private _abortController;
    private _signal;
    constructor(config: IConfig);
    private _getChunks;
    private setMd5;
    private _uploadChunk;
    private _handleUploadChunks;
    private _handleRetry;
    private _handleChunkProgress;
    abort(): void;
    pause(): void;
    resume(): void;
    private toMd5;
}
export declare const upload: (config: IConfig) => UploadChunk;
export {};
